pub enum ClientAuthentication {
Secure {
connect_token: ConnectToken,
},
Unsecure {
protocol_id: u64,
client_id: u64,
socket_id: u8,
server_addr: SocketAddr,
user_data: Option<[u8; 256]>,
},
}Available on crate feature
netcode only.Expand description
Configuration to establish a secure or unsecure connection with the server.
Variants
Secure
Establishes a safe connection with the server using the crate::ConnectToken.
See also crate::ServerAuthentication::Secure
Fields

connect_token: ConnectTokenUnsecure
Establishes an unsafe connection with the server, useful for testing and prototyping.