pub enum NetcodeError {
Show 17 variants
UnavailablePrivateKey,
InvalidPacketType,
InvalidProtocolID,
InvalidVersion,
InvalidSocketId,
PacketTooSmall,
PayloadAboveLimit,
DuplicatedSequence,
NoMoreServers,
Expired,
Disconnected(DisconnectReason),
CryptoError,
NotInHostList,
ClientNotFound,
ClientNotConnected,
IoError(Error),
TokenGenerationError(TokenGenerationError),
}Available on crate feature
netcode only.Expand description
Errors from the renetcode crate.
Variants
No private keys was available while decrypting.
InvalidPacketType
The type of the packet is invalid.
InvalidProtocolID
The connect token has an invalid protocol id.
InvalidVersion
The connect token has an invalid version.
InvalidSocketId
The connect token was transmitted by an invalid socket.
PacketTooSmall
Packet size is too small to be a netcode packet.
PayloadAboveLimit
Payload is above the maximum limit
DuplicatedSequence
The processed packet is duplicated
NoMoreServers
No more host are available in the connect token..
Expired
The connect token has expired.
Disconnected(DisconnectReason)
The client is disconnected.
CryptoError
An error occurred while encrypting or decrypting.
NotInHostList
The server address is not in the connect token.
ClientNotFound
Client was not found.
ClientNotConnected
Client is not connected.
IoError(Error)
IO error.
TokenGenerationError(TokenGenerationError)
An error occurred while generating the connect token.