pub struct NetcodeClientTransport { /* private fields */ }netcode only.Implementations
Sourceimpl NetcodeClientTransport
impl NetcodeClientTransport
Sourcepub fn new(
current_time: Duration,
authentication: ClientAuthentication,
socket: impl ClientSocket,
) -> Result<NetcodeClientTransport, NetcodeError>
pub fn new( current_time: Duration, authentication: ClientAuthentication, socket: impl ClientSocket, ) -> Result<NetcodeClientTransport, NetcodeError>
Makes a new client transport with the given ClientSocket.
Sourcepub fn is_reliable(&self) -> bool
pub fn is_reliable(&self) -> bool
Gets the internal socket’s ClientSocket::is_reliable value.
Sourcepub fn addr(&self) -> Result<SocketAddr, Error>
pub fn addr(&self) -> Result<SocketAddr, Error>
Gets the client’s SocketAddr.
Will return an error if the client doesn’t have an address (e.g. a WebTransport client).
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Returns true if the netcode client is connected.
Sourcepub fn is_connecting(&self) -> bool
pub fn is_connecting(&self) -> bool
Returns true if the netcode client is connecting.
Sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
Returns true if the netcode client is disconnected.
Sourcepub fn time_since_last_received_packet(&self) -> Duration
pub fn time_since_last_received_packet(&self) -> Duration
Returns the duration since the client last received a packet.
Useful to detect timeouts.
Sourcepub fn disconnect(&mut self)
pub fn disconnect(&mut self)
Disconnects the client from the transport layer.
This sends the disconnect packet instantly, use this when closing/exiting games, should use RenetClient::disconnect otherwise.
Sourcepub fn disconnect_reason(&self) -> Option<DisconnectReason>
pub fn disconnect_reason(&self) -> Option<DisconnectReason>
If the client is disconnected, returns the reason.
Sourcepub fn send_packets(
&mut self,
connection: &mut RenetClient,
) -> Result<(), NetcodeTransportError>
pub fn send_packets( &mut self, connection: &mut RenetClient, ) -> Result<(), NetcodeTransportError>
Sends packets to the server.
Should be called every tick.
Sourcepub fn update(
&mut self,
duration: Duration,
client: &mut RenetClient,
) -> Result<(), NetcodeTransportError>
pub fn update( &mut self, duration: Duration, client: &mut RenetClient, ) -> Result<(), NetcodeTransportError>
Advances the transport by the duration, and receive packets from the network.