ServerCertHash

Struct ServerCertHash 

pub struct ServerCertHash {
    pub hash: [u8; 32],
}
Available on crate feature netcode only.
SHA-256 hash of a DER-encoded certificate.

The certificate must be an X.509v3 certificate that has a validity period of less that 2 weeks, and the current time must be within that validity period. The format of the public key in the certificate depends on the implementation, but must minimally include ECDSA with the secp256r1 (NIST P-256) named group, and must not include RSA keys. See the docs.

Fields

hash: [u8; 32]