pub struct ServerCertHash {
pub hash: [u8; 32],
}Available on crate feature
netcode only.Expand description
SHA-256 hash of a DER-encoded certificate.
The certificate must be an X.509v3 certificate that has a validity period of less that 2 weeks, and the current time must be within that validity period. The format of the public key in the certificate depends on the implementation, but must minimally include ECDSA with the secp256r1 (NIST P-256) named group, and must not include RSA keys. See the docs.
Fields
hash: [u8; 32]Trait Implementations
Sourceimpl Clone for ServerCertHash
impl Clone for ServerCertHash
Sourcefn clone(&self) -> ServerCertHash
fn clone(&self) -> ServerCertHash
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ServerCertHash
impl Debug for ServerCertHash
Sourceimpl<'de> Deserialize<'de> for ServerCertHash
impl<'de> Deserialize<'de> for ServerCertHash
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ServerCertHash, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ServerCertHash, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for ServerCertHash
impl Serialize for ServerCertHash
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more